//
//  DateFormatterServiceTests.swift
//  SayTheirNamesTests
//
//  Copyright (c) 2020 Say Their Names Team (https://github.com/Say-Their-Name)
//
//  Permission is hereby granted, free of charge, to any person obtaining a copy
//  of this software and associated documentation files (the "Software"), to deal
//  in the Software without restriction, including without limitation the rights
//  to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
//  copies of the Software, and to permit persons to whom the Software is
//  furnished to do so, subject to the following conditions:
//
//  The above copyright notice and this permission notice shall be included in
//  all copies or substantial portions of the Software.
//
//  THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
//  IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
//  FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
//  AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
//  LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
//  OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
//  THE SOFTWARE.

import XCTest
@testable import Say_Their_Names

class DateFormatterServiceTests: XCTestCase {
    
    func testDateOfIncidentFormatter() {
        guard let date = Date.dateFrom(year: 2020, month: 06, day: 03) else {
            XCTFail("unable to create date")
            return
        }
        let dateFormatterService = DateFormatterService(localeProvider: { Locale(identifier: "en_US") })
        let formattedDate = dateFormatterService.dateOfIncidentString(from: date)
        XCTAssertEqual(formattedDate, "6/3/20", "The date should be formatted according to US date format")
    }
    
    func testDateOfIncidentFormatterRespectsLocale() {
        guard let date = Date.dateFrom(year: 2020, month: 06, day: 03) else {
            XCTFail("unable to create date")
            return
        }
        let dateFormatterService = DateFormatterService(localeProvider: { Locale(identifier: "en_DK") })
        let formattedDate = dateFormatterService.dateOfIncidentString(from: date)
        XCTAssertEqual(formattedDate, "03/06/2020", "The date should be formatted according to DK date format")
    }
}

extension Date {
    fileprivate static func dateFrom(year: Int, month: Int,  day: Int, hour: Int = 0, minute: Int = 0, second: Int = 0) -> Date? {
        var components = DateComponents()
        components.year = year
        components.month = month
        components.day = day
        components.hour = hour
        components.minute = minute
        components.second = second
        components.timeZone = Calendar.current.timeZone

        return Calendar.current.date(from: components)
    }
}
